/**
 * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
 *
 * The contents of this file are subject to the terms of the Liferay Enterprise
 * Subscription License ("License"). You may not use this file except in
 * compliance with the License. You can obtain a copy of the License by
 * contacting Liferay, Inc. See the License for the specific language governing
 * permissions and limitations under the License, including but not limited to
 * distribution rights of the Software.
 *
 *
 *
 */

package com.liferay.blogs.rest.internal.resource;

import com.liferay.blogs.exception.NoSuchEntryException;
import com.liferay.blogs.model.BlogsEntry;
import com.liferay.blogs.service.BlogsEntryService;
import com.liferay.portal.kernel.exception.PortalException;

import javax.ws.rs.NotFoundException;
import javax.ws.rs.Path;
import javax.ws.rs.PathParam;

import org.osgi.service.component.annotations.Component;
import org.osgi.service.component.annotations.Reference;

/**
 * @author Alejandro Hernández
 */
@Component(immediate = true, service = BlogsRootResource.class)
@Path("/")
public class BlogsRootResource {

	@Path("/{entryId}")
	public BlogsEntryResource getBlogsEntryResource(
			@PathParam("entryId") long entryId)
		throws PortalException {

		BlogsEntry blogsEntry = null;

		try {
			blogsEntry = _blogsEntryService.getEntry(entryId);
		}
		catch (NoSuchEntryException nsee) {
			throw new NotFoundException(nsee);
		}

		return new BlogsEntryResource(blogsEntry);
	}

	@Reference
	private BlogsEntryService _blogsEntryService;

}